==> savane-1.0.7+4.tar.gz: savane-1.0.7+4/frontend/php/admin/gnueval.php <==
<?php
// This file is part of the Savane project
// <http://gna.org/projects/savane/>
//
// $Id: gnueval.php,v 1.14 2005/01/27 14:56:34 beuc Exp $
//
//
//  The Savannah Project
//  Copyright 2000-2003 (c) Free Software Foundation
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
//
//
//

require "../include/pre.php";

function gnuevalconfirm_email($group_id) 
{
	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':gnuevalconfirm_email($group_id) ';
  $res_grp = db_query("SELECT * FROM groups WHERE group_id='$group_id'");

  if (db_numrows($res_grp) < 1) {
    echo ("Group [ $group_id ] does not exist. Shame on you, sysadmin.");
  }

  $row_grp = db_fetch_array($res_grp);

  $res_admins = db_query("SELECT user.user_name,user.email FROM user,user_group WHERE "
			 . "user.user_id=user_group.user_id AND user_group.group_id='$group_id' AND "
			 . "user_group.admin_flags='A'");

  if (db_numrows($res_admins) < 1) {
    echo ("Group [ $group_id ] does not seem to have any administrators.");
  }

  $usr = db_fetch_array($res_admins);

  $to = "gnueval-input@gnu.org,savannah-hackers@gnu.org,".$usr['email'];
  $message = 
    'Hi,

The following project was submitted to Savannah. It needs evaluation to
become a GNU package, can you give it a look, please ? 

Submitter: <'.$usr['email'].'>
Project Full Name:  '.$row_grp['group_name'].'
Project System Name:  '.$row_grp['unix_group_name'].'
License:  '.$row_grp['license'].'
Approval URL: https://savannah.gnu.org/admin/groupedit.php?group_id='.$group_id.'
Description: '.$row_grp['register_purpose'].'

 -- the Savannah admin';

  sendmail_mail("savannah-hackers@gnu.org",
		$to,
		"[Savannah] " . $row_grp['unix_group_name'] . " want to be a GNU package",
		wordwrap($message));


}

session_require(array('group'=>'1','admin_flags'=>'A'));

$HTML->header(array('title'=>"GNU Eval team request"));

gnuevalconfirm_email($group_id);

print "<P>Mail successfully sent.";

$HTML->footer(array());
?>

==> savane-1.2.tar.gz: savane-1.2/frontend/php/admin/gnueval.php <==
<?php
// This file is part of the Savane project
// <http://gna.org/projects/savane/>
//
// $Id: gnueval.php,v 1.15 2005/06/30 17:19:33 toddy Exp $
//
//
//  The Savannah Project
//  Copyright 2000-2003 (c) Free Software Foundation
// 
// The Savane project is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// The Savane project is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with the Savane project; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//
//
//

require "../include/pre.php";

function gnuevalconfirm_email($group_id) 
{
	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':gnuevalconfirm_email($group_id) ';
  $res_grp = db_query("SELECT * FROM groups WHERE group_id='$group_id'");

  if (db_numrows($res_grp) < 1) {
    echo ("Group [ $group_id ] does not exist. Shame on you, sysadmin.");
  }

  $row_grp = db_fetch_array($res_grp);

  $res_admins = db_query("SELECT user.user_name,user.email FROM user,user_group WHERE "
			 . "user.user_id=user_group.user_id AND user_group.group_id='$group_id' AND "
			 . "user_group.admin_flags='A'");

  if (db_numrows($res_admins) < 1) {
    echo ("Group [ $group_id ] does not seem to have any administrators.");
  }

  $usr = db_fetch_array($res_admins);

  $to = "gnueval-input@gnu.org,savannah-hackers@gnu.org,".$usr['email'];
  $message = 
    'Hi,

The following project was submitted to Savannah. It needs evaluation to
become a GNU package, can you give it a look, please ? 

Submitter: <'.$usr['email'].'>
Project Full Name:  '.$row_grp['group_name'].'
Project System Name:  '.$row_grp['unix_group_name'].'
License:  '.$row_grp['license'].'
Approval URL: https://savannah.gnu.org/admin/groupedit.php?group_id='.$group_id.'
Description: '.$row_grp['register_purpose'].'

 -- the Savannah admin';

  sendmail_mail("savannah-hackers@gnu.org",
		$to,
		"[Savannah] " . $row_grp['unix_group_name'] . " want to be a GNU package",
		wordwrap($message));


}

session_require(array('group'=>'1','admin_flags'=>'A'));

$HTML->header(array('title'=>"GNU Eval team request"));

gnuevalconfirm_email($group_id);

print "<P>Mail successfully sent.";

$HTML->footer(array());
?>
